Module stmt

Module stmt 

Statement code generation.

Statements do not produce a value on the stack (they consume their results or have side effects like set).

Functions

emit_stmt
Emit a single statement.
emit_stmts
Emit a slice of statements.