Main WASM module assembler.
Orchestrates the code generation pipeline:
- Analyse the AST and collect metadata (state fields, actions, views, etc.)
- Build the data segment (intern string constants)
- Emit runtime helper functions
- Emit space-level functions (init, dispatch, render, get_state, …)
- Assemble all WASM sections into a valid module
- Validate with
wasmparser
Structs
- Data
Segment Tracker Clone - A clonable wrapper around key fields from
DataSegmentTracker. - Func
Context - State maintained while generating code for a single function body.
- Lambda
Body - A lambda body collected during expression codegen for deferred compilation.
Functions
- compile
- Compile a validated PEPL
Programinto a.wasmbinary. - compile_
with_ source_ map - Compile a validated PEPL
Programand return both the WASM binary and aSourceMapmapping WASM function indices to PEPL source spans.