Statement code generation.
Statements do not produce a value on the stack (they consume their results
or have side effects like set).
Functions
- emit_
stmt - Emit a single statement.
- emit_
stmts - Emit a slice of statements.
Statement code generation.
Statements do not produce a value on the stack (they consume their results
or have side effects like set).